 .. toctree::
   :maxdepth: 2
  
.. include:: README.rst

Links
==========
.. toctree::
   F3AST On Github <http://github.com/skoricius/f3ast>

Install
==========

.. toctree::
   :maxdepth: 2
	      
   install

Getting started
==============================

.. toctree::
   :maxdepth: 2
	      
   getting_started

Examples
==========

.. toctree::
   :maxdepth: 2
	      
   examples

API Reference
=================================

.. toctree::
   :maxdepth: 1
   
   API Reference <f3ast>